import re

import execjs
import requests
from lxml.etree import HTML


def _execute_code_generating_video_src_url(code):
    lines = code.strip().split(";")
    result = {}

    for l in lines:
        try:
            id_ = re.search(r"document\.getElementById\('(.+?)'\)", l).group(1)
        except:
            continue
        expr = l.split("=", 1)[1]
        url = execjs.eval(expr)

        result[id_] = url

    return result


def resolve(embed_url, referer=None) -> requests.models.Response:
    """
    :param embed_url: this param only accept url like https://streamtape.com/e/LqG4K9a8PKiRk1J
    :param referer:
    :return:
    """
    response = requests.get(embed_url, headers={"Referer": referer})
    if response.status_code == 500 or response.status_code == 404:
        return

    script_list = HTML(response.text).xpath("//script/text()")

    code_generating_video_src_url = list(filter(lambda s: "get_video" in s, script_list))[0]
    document_ready_code = list(filter(lambda s: "$(document).ready(function" in s, script_list))[0]

    id_ = re.search(r"\$\(['|\"]#(.+?)['|\"]\)\.", document_ready_code).group(1)
    result = _execute_code_generating_video_src_url(code_generating_video_src_url)

    src_url = f"https:{result[id_]}"
    response = requests.get(src_url, stream=True)

    return response


import requests
from lxml.etree import HTML


def resolve(web_url, referer=None):
    response = requests.get(web_url)
    video_src_url = list(filter(lambda e: "?tokenkey" in e, HTML(response.text).xpath("//source/@src")))[0]
    return requests.get(video_src_url, headers={"Referer": web_url}, stream=True)


from distutils.core import setup
from setuptools import find_packages

with open("README.md", "r") as f:
    long_description = f.read()

setup(name='video-stream-resolving',  # 包名
      version='1.1.1',  # 版本号
      description='Resolving some video stream',
      long_description=long_description,
      long_description_content_type="text/markdown",
      author='magicalbomb',
      author_email='17826800084@163.com',
      # url='https://mp.weixin.qq.com/s/9FQ-Tun5FbpBepBAsdY62w',
      install_requires=[
          "PyExecjs",
          "requests",
          "lxml",
      ],
      license='BSD License',
      packages=find_packages(),
      platforms=["all"],
      classifiers=[
          'Intended Audience :: Developers',
          'Operating System :: OS Independent',
          'Natural Language :: Chinese (Simplified)',
          'Programming Language :: Python',
          'Programming Language :: Python :: 3.5',
          'Programming Language :: Python :: 3.6',
          'Programming Language :: Python :: 3.7',
          'Programming Language :: Python :: 3.8',
          'Topic :: Software Development :: Libraries'
      ],
      )



import re

import requests
requests.packages.urllib3.util.ssl_.DEFAULT_CIPHERS = 'ALL'


def resolve(embed_url, referer=None):
    """
    :param embed_url: This params only accept url which host is dood.to, doodstream.com or dood.watch
    :param referer:
    :return:
    """
    # TODO: dood 应是封禁了 python requests 的指纹， 最好的办法还是用无头浏览器

    video_id = embed_url.split("/")[-1]

    # headers = {
    #     'authority': 'dood.to',
    #     'accept': '*/*',
    #     'x-requested-with': 'XMLHttpRequest',
    #     'user-agent': 'Mozilla/5.0 (Linux; Android 6.0; Nexus 5 Build/MRA58N) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/83.0.4103.116 Mobile Safari/537.36',
    #     'sec-fetch-site': 'same-origin',
    #     'sec-fetch-mode': 'navigate',
    #     'sec-fetch-dest': 'iframe',
    #     'referer': 'https://dood.to/d/$id',
    #     'accept-language': 'zh-CN,zh;q=0.9,en;q=0.8,zh-TW;q=0.7'
    # }
    headers = {
        "Accept": "*/*",
        "Accept-Encoding": "gzip, deflate, br",
        "Connection": "keep-alive",
    }
    response = requests.get(f"https://dood.to/e/{video_id}", headers=headers, proxies={"https": "http://localhost:8866"}, verify=False)
    video_base_url = re.search(r"(?<=\')/pass_md5.*(?=\')", response.text)

    request_code = """
let https = require('https')
let options = {
  hostname: 'dood.to',
  port: 443,
  path: '/e/5xl5c8djmc4z',
  method: 'GET'
}

let req = https.request(options, res => {
  console.log(`状态码: ${res.statusCode}`)

  res.on('data', d => {
    process.stdout.write(d)
  })
})

req.on('error', error => {
  console.error(error)
})

req.end()
    """
